; *******************************************************************
; *** This software is copyright 2004 by Michael H Riley          ***
; *** You have permission to use, modify, copy, and distribute    ***
; *** this software so long as this copyright notice is retained. ***
; *** This software may not be used in commercial applications    ***
; *** without express written permission from the author.         ***
; *******************************************************************

include    bios.inc
include    kernel.inc

           org     8000h
           db      'VER',0
           dw      9000h
           dw      endrom+7000h
           dw      2000h
           dw      endrom-2000h
           dw      2000h
           db      0

           org     2000h
           br      start               ; jump past version info

include    date.inc

start:     ldn     ra                  ; get byte from passed args
           bnz     filever             ; jump for file version
           ldi     high buffer         ; point to buffer
           phi     rf
           ldi     low buffer
           plo     rf
           ldi     04h                 ; point to os data
           phi     rb
           ldi     0
           plo     rb
           lda     rb                  ; get major version number
           plo     rd                  ; prepare for conversion
           ldi     0                   ; high byte is zero
           phi     rd
           sep     scall               ; convert number
           dw      donum
           ldi     '.'                 ; put a dot into the buffer
           str     rf
           inc     rf
           lda     rb                  ; get minor version number
           plo     rd                  ; prepare for conversion
           ldi     0                   ; high byte is zero
           phi     rd
           sep     scall               ; convert number
           dw      donum
           ldi     '.'                 ; put a dot into the buffer
           str     rf
           inc     rf
           lda     rb                  ; get minor version number
           plo     rd                  ; prepare for conversion
           ldi     0                   ; high byte is zero
           phi     rd
           sep     scall               ; convert number
           dw      donum
           ldi     ' '                 ; put a dot into the buffer
           str     rf
           inc     rf
           ldi     'B'                 ; put a dot into the buffer
           str     rf
           inc     rf
           ldi     'u'                 ; put a dot into the buffer
           str     rf
           inc     rf
           ldi     'i'                 ; put a dot into the buffer
           str     rf
           inc     rf
           ldi     'l'                 ; put a dot into the buffer
           str     rf
           inc     rf
           ldi     'd'                 ; put a dot into the buffer
           str     rf
           inc     rf
           ldi     ' '                 ; put a dot into the buffer
           str     rf
           inc     rf
           lda     rb                  ; get it
           phi     rd
           lda     rb
           plo     rd
           sep     scall               ; convert number
           dw      donum
           ldi     ' '                 ; put a dot into the buffer
           str     rf
           inc     rf

dodate:    lda     rb                  ; get month
           plo     rd                  ; prepare for conversion
           ldi     0                   ; high byte is zero
           phi     rd
           sep     scall               ; convert number
           dw      donum
           ldi     '/'                 ; put a dot into the buffer
           str     rf
           inc     rf
           lda     rb                  ; get day
           plo     rd                  ; prepare for conversion
           ldi     0                   ; high byte is zero
           phi     rd
           sep     scall               ; convert number
           dw      donum
           ldi     '/'                 ; put a dot into the buffer
           str     rf
           inc     rf
           lda     rb                  ; get year
           phi     rd                  ; prepare for conversion
           lda     rb
           plo     rd
           sep     scall               ; convert number
           dw      donum

           ldi     13                  ; add termination
           str     rf
           inc     rf
           ldi     10
           str     rf
           inc     rf
           ldi     0
           str     rf
           inc     rf
           ldi     high buffer         ; point to buffer
           phi     rf
           ldi     low buffer
           plo     rf
           sep     scall               ; display version
           dw      f_msg
           sep     sret                ; and return to caller

donum:     glo     rd                  ; check for zero
           bnz     nonzero             ; jump if not zero
           ldi     '0'                 ; store zero into buffer
           str     rf
           inc     rf
           sep     sret                ; and return
nonzero:   sep     scall               ; convert number
           dw      f_intout
           sep     sret                ; and return to caller

filever:   ghi     ra                  ; transfer args to rf
           phi     rf
           glo     ra
           plo     rf
loop1:     lda     ra                  ; find end of filename
           smi     33                  ; looking for a space or less
           bdf     loop1               ; loop until found
           dec     ra                  ; back up 1
           ldi     0                   ; need to terminate it
           str     ra
           ldi     high fildes         ; get file descriptor
           phi     rd
           ldi     low fildes
           plo     rd
           ldi     0                   ; flags for open
           plo     r7
           sep     scall               ; attempt to open file
           dw      o_open
           bnf     opened              ; jump if file was opened
           ldi     high errmsg         ; get error message
           phi     rf
           ldi     low errmsg
           plo     rf
           sep     scall               ; display it
           dw      f_msg
           lbr     o_wrmboot           ; and return to os
opened:    ldi     high buffer2        ; set up for read
           phi     rf
           ldi     low buffer2
           plo     rf
           ldi     0                   ; need to read 8 bytes
           phi     rc
           ldi     8
           plo     rc
           sep     scall               ; read them
           dw      o_read
           ldi     high buffer2        ; set up for read
           phi     rf
           ldi     low buffer2
           plo     rf
           ldi     0                   ; need to read 4 bytes
           phi     rc
           ldi     4
           plo     rc
           sep     scall               ; read them
           dw      o_read
           sep     scall               ; close the file
           dw      o_close
           ldi     high buffer2        ; set up for display
           phi     rb
           ldi     low buffer2
           plo     rb
           ldi     high buffer         ; setup output buffer
           phi     rf
           ldi     low buffer
           plo     rf
           br      dodate               ; jump for display


errmsg:    db      'File not found',10,13,0

fildes:    db      0,0,0,0
           dw      dta
           db      0,0
           db      0
           db      0,0,0,0
           dw      0,0
           db      0,0,0,0

endrom:    equ     $

dta:       ds      512

buffer2:   ds      8

buffer:    db      0
